==> estateplat-common-1.2.4-20220811.072604-1081-sources.jar: cn/gtmap/estateplat/model/exchange/share/GxWwSqxxGhxx.java <==
package cn.gtmap.estateplat.model.exchange.share;

import javax.persistence.Id;
import javax.persistence.Table;


/**
 * @author <a href="mailto:chenjia@gtmap.cn">chenjia</a>
 * @version 1.0
 * @description 外网申请过户信息表
 */
@Table(name = "GX_WW_SQXX_GHXX")
public class GxWwSqxxGhxx {
    @Id
    private String ghxxid;
    private String sqxxid;
    private String ssfgh;
    private String dsfgh;
    private String qsfgh;
    private String gdsfgh;
    private String wlsfgh;
    private String yskkh;
    private String ydkkh;
    private String ygdkh;
    private String yrqkh;
    private String yskhzmc;//原水卡户主名称
    private String xskhzmc;//新水卡户主名称
    private String ydkhzmc;//原电卡户主名称
    private String xdkhzmc;//新电卡户主名称
    private String yrqkhzmc;//原燃气卡户主名称
    private String xrqkhzmc;//新燃气卡户主名称

    public String getGhxxid() {
        return ghxxid;
    }

    public void setGhxxid(String ghxxid) {
        this.ghxxid = ghxxid;
    }

    public String getSqxxid() {
        return sqxxid;
    }

    public void setSqxxid(String sqxxid) {
        this.sqxxid = sqxxid;
    }

    public String getSsfgh() {
        return ssfgh;
    }

    public void setSsfgh(String ssfgh) {
        this.ssfgh = ssfgh;
    }

    public String getDsfgh() {
        return dsfgh;
    }

    public void setDsfgh(String dsfgh) {
        this.dsfgh = dsfgh;
    }

    public String getQsfgh() {
        return qsfgh;
    }

    public void setQsfgh(String qsfgh) {
        this.qsfgh = qsfgh;
    }

    public String getGdsfgh() {
        return gdsfgh;
    }

    public void setGdsfgh(String gdsfgh) {
        this.gdsfgh = gdsfgh;
    }

    public String getWlsfgh() {
        return wlsfgh;
    }

    public void setWlsfgh(String wlsfgh) {
        this.wlsfgh = wlsfgh;
    }

    public String getYskkh() {
        return yskkh;
    }

    public void setYskkh(String yskkh) {
        this.yskkh = yskkh;
    }

    public String getYdkkh() {
        return ydkkh;
    }

    public void setYdkkh(String ydkkh) {
        this.ydkkh = ydkkh;
    }

    public String getYgdkh() {
        return ygdkh;
    }

    public void setYgdkh(String ygdkh) {
        this.ygdkh = ygdkh;
    }

    public String getYrqkh() {
        return yrqkh;
    }

    public void setYrqkh(String yrqkh) {
        this.yrqkh = yrqkh;
    }

    public String getYskhzmc() {
        return yskhzmc;
    }

    public void setYskhzmc(String yskhzmc) {
        this.yskhzmc = yskhzmc;
    }

    public String getXskhzmc() {
        return xskhzmc;
    }

    public void setXskhzmc(String xskhzmc) {
        this.xskhzmc = xskhzmc;
    }

    public String getYdkhzmc() {
        return ydkhzmc;
    }

    public void setYdkhzmc(String ydkhzmc) {
        this.ydkhzmc = ydkhzmc;
    }

    public String getXdkhzmc() {
        return xdkhzmc;
    }

    public void setXdkhzmc(String xdkhzmc) {
        this.xdkhzmc = xdkhzmc;
    }

    public String getYrqkhzmc() {
        return yrqkhzmc;
    }

    public void setYrqkhzmc(String yrqkhzmc) {
        this.yrqkhzmc = yrqkhzmc;
    }

    public String getXrqkhzmc() {
        return xrqkhzmc;
    }

    public void setXrqkhzmc(String xrqkhzmc) {
        this.xrqkhzmc = xrqkhzmc;
    }
}

==> estateplat-common-1.2.4-20231207.065620-1205-sources.jar: cn/gtmap/estateplat/model/exchange/share/GxWwSqxxGhxx.java <==
package cn.gtmap.estateplat.model.exchange.share;

import javax.persistence.Id;
import javax.persistence.Table;


/**
 * @author <a href="mailto:chenjia@gtmap.cn">chenjia</a>
 * @version 1.0
 * @description 外网申请过户信息表
 */
@Table(name = "GX_WW_SQXX_GHXX")
public class GxWwSqxxGhxx {
    @Id
    private String ghxxid;
    private String sqxxid;
    private String ssfgh;//水是否过户
    private String dsfgh;//电是否过户
    private String qsfgh;//气是否过户
    private String gdsfgh;//广电是否过户
    private String wlsfgh;//网络是否过户
    private String yskkh;//原水卡卡号
    private String ydkkh;//原电卡卡号
    private String ygdkh;//原广电卡号
    private String yrqkh;//原燃气卡号
    private String yskhzmc;//原水卡户主名称
    private String xskhzmc;//新水卡户主名称
    private String ydkhzmc;//原电卡户主名称
    private String xdkhzmc;//新电卡户主名称
    private String yrqkhzmc;//原燃气卡户主名称
    private String xrqkhzmc;//新燃气卡户主名称
    private String gddwbm;//供电单位编码
    private String yhzsfzh;//原户主身份证号
    private String yhzlxdh;//原户主联系电话
    private Double dqfje;//电欠费金额
    private String sfqsdf;//是否清算电费

    public String getGhxxid() {
        return ghxxid;
    }

    public void setGhxxid(String ghxxid) {
        this.ghxxid = ghxxid;
    }

    public String getSqxxid() {
        return sqxxid;
    }

    public void setSqxxid(String sqxxid) {
        this.sqxxid = sqxxid;
    }

    public String getSsfgh() {
        return ssfgh;
    }

    public void setSsfgh(String ssfgh) {
        this.ssfgh = ssfgh;
    }

    public String getDsfgh() {
        return dsfgh;
    }

    public void setDsfgh(String dsfgh) {
        this.dsfgh = dsfgh;
    }

    public String getQsfgh() {
        return qsfgh;
    }

    public void setQsfgh(String qsfgh) {
        this.qsfgh = qsfgh;
    }

    public String getGdsfgh() {
        return gdsfgh;
    }

    public void setGdsfgh(String gdsfgh) {
        this.gdsfgh = gdsfgh;
    }

    public String getWlsfgh() {
        return wlsfgh;
    }

    public void setWlsfgh(String wlsfgh) {
        this.wlsfgh = wlsfgh;
    }

    public String getYskkh() {
        return yskkh;
    }

    public void setYskkh(String yskkh) {
        this.yskkh = yskkh;
    }

    public String getYdkkh() {
        return ydkkh;
    }

    public void setYdkkh(String ydkkh) {
        this.ydkkh = ydkkh;
    }

    public String getYgdkh() {
        return ygdkh;
    }

    public void setYgdkh(String ygdkh) {
        this.ygdkh = ygdkh;
    }

    public String getYrqkh() {
        return yrqkh;
    }

    public void setYrqkh(String yrqkh) {
        this.yrqkh = yrqkh;
    }

    public String getYskhzmc() {
        return yskhzmc;
    }

    public void setYskhzmc(String yskhzmc) {
        this.yskhzmc = yskhzmc;
    }

    public String getXskhzmc() {
        return xskhzmc;
    }

    public void setXskhzmc(String xskhzmc) {
        this.xskhzmc = xskhzmc;
    }

    public String getYdkhzmc() {
        return ydkhzmc;
    }

    public void setYdkhzmc(String ydkhzmc) {
        this.ydkhzmc = ydkhzmc;
    }

    public String getXdkhzmc() {
        return xdkhzmc;
    }

    public void setXdkhzmc(String xdkhzmc) {
        this.xdkhzmc = xdkhzmc;
    }

    public String getYrqkhzmc() {
        return yrqkhzmc;
    }

    public void setYrqkhzmc(String yrqkhzmc) {
        this.yrqkhzmc = yrqkhzmc;
    }

    public String getXrqkhzmc() {
        return xrqkhzmc;
    }

    public void setXrqkhzmc(String xrqkhzmc) {
        this.xrqkhzmc = xrqkhzmc;
    }

    public String getGddwbm() {
        return gddwbm;
    }

    public void setGddwbm(String gddwbm) {
        this.gddwbm = gddwbm;
    }

    public String getYhzsfzh() {
        return yhzsfzh;
    }

    public void setYhzsfzh(String yhzsfzh) {
        this.yhzsfzh = yhzsfzh;
    }

    public String getYhzlxdh() {
        return yhzlxdh;
    }

    public void setYhzlxdh(String yhzlxdh) {
        this.yhzlxdh = yhzlxdh;
    }

    public Double getDqfje() {
        return dqfje;
    }

    public void setDqfje(Double dqfje) {
        this.dqfje = dqfje;
    }

    public String getSfqsdf() {
        return sfqsdf;
    }

    public void setSfqsdf(String sfqsdf) {
        this.sfqsdf = sfqsdf;
    }
}
